==> Paws-0.01.tar.gz: Paws-0.01/lib/Paws/CloudFormation/CancelUpdateStack.pm <==

package Paws::CloudFormation::CancelUpdateStack {
  use Moose;
  has StackName => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'CancelUpdateStack');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudFormation::CancelUpdateStack - Arguments for method CancelUpdateStack on Paws::CloudFormation

=head1 DESCRIPTION

This class represents the parameters used for calling the method CancelUpdateStack on the 
AWS CloudFormation service. Use the attributes of this class
as arguments to method CancelUpdateStack.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to CancelUpdateStack.

As an example:

  $service_obj->CancelUpdateStack(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> StackName => Str

  

The name or the unique identifier associated with the stack.












=head1 SEE ALSO

This class forms part of L<Paws>, and documents parameters for CancelUpdateStack in Paws::CloudFormation

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.05.tar.gz: Paws-0.05/lib/Paws/CloudFormation/CancelUpdateStack.pm <==

package Paws::CloudFormation::CancelUpdateStack {
  use Moose;
  has StackName => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'CancelUpdateStack');
  class_has _returns => (isa => 'Str', is => 'ro');
  class_has _result_key => (isa => 'Str', is => 'ro');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::CloudFormation::CancelUpdateStack - Arguments for method CancelUpdateStack on Paws::CloudFormation

=head1 DESCRIPTION

This class represents the parameters used for calling the method CancelUpdateStack on the 
AWS CloudFormation service. Use the attributes of this class
as arguments to method CancelUpdateStack.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to CancelUpdateStack.

As an example:

  $service_obj->CancelUpdateStack(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> StackName => Str

  

The name or the unique identifier associated with the stack.












=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method CancelUpdateStack in L<Paws::CloudFormation>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
